@@ -5,10 +5,12 @@
 
 #ifndef _EXT_LZMA_H
 
-#include <Alloc.h>
 #include <LzmaDec.h>
 #include <Lzma2Dec.h>
 
+#include "contrib/minizip/ioapi.h"
+#include "contrib/minizip/unzip.h"
+
 int hc_lzma1_decompress (const unsigned char *in, SizeT *in_len, unsigned char *out, SizeT *out_len, const char *props);
 int hc_lzma2_decompress (const unsigned char *in, SizeT *in_len, unsigned char *out, SizeT *out_len, const char *props);
 
